@@ -6,7 +6,7 @@ from djangomaster.conf import settings
 from djangomaster.views import MasterMixin
 
 
-class HomeView(ListView, MasterMixin):
+class HomeView(MasterMixin, ListView):
     template_name = 'djangomaster/home.html'
     context_object_name = 'object'
     menu_item = 'home'
@@ -18,7 +18,6 @@ class HomeView(ListView, MasterMixin):
 
         return ret
 
-
     def get_requirements(self):
         if settings.BASE_DIR is None:
             return {'BASE_DIR_ERROR': True}
