@@ -9,7 +9,7 @@ from django.views.generic import ListView
 from djangomaster.views import MasterMixin
 
 
-class SettingsListView(ListView, MasterMixin):
+class SettingsListView(MasterMixin, ListView):
     template_name = 'djangomaster/settings.html'
     context_object_name = 'settings_list'
     menu_item = 'settings'
